version 8.2
clear
set logtype text
set more off
set matsize 200

capture log close
log using "brazrloc/logs/subsibge-ivs.log", replace

// NIVEL 50 AND SUBS_IBGE STRUCTURES  (similar to "brazrloc/%stata/%1prep-data/sector-data.do")

tempfile niv2subs
insheet using "brazaux/conc/sec/niv50-subsibge-manual.csv", names comma clear  // compare "brazrloc/auxil/niv50-subsibge-pseudoconc.csv" (from %4tex/compadv-by-secagg.do)
label var subsibge_num "Subsector IBGE"
label var niv50_num "Sector (Nivel 50)"
count if niv50_num==niv50_num[_n-1] | niv50_num==niv50_num[_n+1]
if `r(N)'>0  STOP  // concordance incomplete
duplicates tag niv50_num, gen(_dupl)
qui count if _dupl>0
if `r(N)'>0  STOP  // not a unique nivel 50 list
drop _dupl
rename niv50 niv50desc
rename niv50_num niv50
rename subsibge subsibgedesc
rename subsibge_num subsibge
compress
keep niv50 subsibge
sort niv50
save `niv2subs'

* US PPI
tempfile usppi
use "brazprod/addl/ivs/ppi-us/us-ppi.dta", clear
gen byte niv50 = int(niv100/100)
label var niv50 "Sector (Nivel 50)"
collapse (mean) ppi, by(niv50 year)
label var ppi "BLS PPI (12-months mean)"
sort niv50 year
joinby niv50 using `niv2subs', unmatched(both) _merge(_merge)
tab _m
tab niv50 if _m==1
tab niv50 if _m==2
drop if _m~=3
drop _m
collapse (mean) ppi, by(subsibge year)
label var ppi "U.S. BLS PPI (12-months mean)"
rename ppi usppi
rename subsibge subs_ibge
drop if year<1986 | year>2000
compress
sort subs_ibge year
save `usppi'

* Complete file
use "brazrloc/auxil/wtf-data-by-sitc4.dta", clear
drop if year<1986 | year>2000
sort subs_ibge year
joinby subs_ibge year using `usppi', unmatched(both) _merge(_merge)
tab _m
tab subs if _m==1
tab year if _m==1
drop _m
preserve

* Assign manufacturing mean to non-manufacturing sectors
tempfile nonmanf snglsec
drop if year<1986 | year>2000
collapse (mean) imp_* usppi, by(year) fast
sort year
save `snglsec'
gen byte subs_ibge = 1
forvalues i = 2/26 {
  append using `snglsec'
  qui replace subs_ibge = `i' if subs_ibge==.
  }
order subs_ibge year
sort subs_ibge year
save `nonmanf'

* Assemble in single file
restore
sort subs_ibge year
merge subs_ibge year using `nonmanf', update
tab _m
drop _m
compress

sort subs_ibge year
save "brazrloc/auxil/subsibge-ivs.dta", replace

log close

