version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/metromale-prime"

capture log close
log using "brazrloc/logs/accessions-metromale-prime-cnae.log", replace

local maxiter $maxiter

local focallst "cnae_balcadv cnae_balcadv_tarf firm_indexp firm_indexp_tarf"
local addlst   "cnae_balcadv_indexp cnae_balcadv_indexp_tarf"
local cntrlfrm "cnae_secrealx cnae_fdiflw cnae_herfsale plant_lnempl plant_indprim plant_indhigh plant_indwhittot"
local cntrlwrk "indprof indtech indwhit indsklb"
local addlwrkr "indhigh indscoll indgrad" 
local endog    "cnae_tarfoutp cnae_tarfintm cnae_reffpen"
local baseiv   "cnae_dollar cnae_ppieu cnae_ppinam"
local expiv    "imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU"

* SUBSECTOR IBGE VARIABLES, BRAZILIAN PRIME-AGE MALES
*----------------------------------------------------

capture confirm file "brazrloc/data/accessions-metromale-prime-cnae.dta"
if _rc ~= 0 {
use wid ano identificad mes_adm rem_media subs_ibge clas_cnae_95 tipo_adm fx_etaria grau_instr cbogrp occagg if ano<=1998 using "brazrloc/data/wid-draw-workers-metro-male", clear
merge wid using "brazrloc/data/wid-draw-workers-metro-male-subsample", nokeep  // _m==2 possible b/c ano<=1998
drop if _m==1
drop _m
drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
drop fx_etaria
rename ano year
sort wid year 

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-cnae.sas)
drop if identificad==.
drop if year==.

* identify accession (excluding transfer)
gen byte indhire = (mes_adm > 0 & tipo_adm~=0 & tipo_adm~=3 & tipo_adm~=4)
label var indhire "Indic.: Accession"
drop tipo_adm

* keep first employment per year
egen byte _firstjob = min(mes_adm), by(wid year)
gen byte indexcl = (mes_adm~=_firstjob)
label var indexcl "Indic.: Not first job in year"
drop _firstjob

* keep employment with highest pay if more than one first employment per year (random drop for pay ties)
sort wid year indexcl rem_media
by wid year indexcl: replace indexcl=1 if _n~=_N

// SECTOR VARIABLES, MAPPING WITH CNAE (CNAE AT PLANT LEVEL)

* use mode CNAE 95 sector at plant-level in years prior to 95, and for years with missing information
sort identificad
merge identificad using "rais/base-agg/cnpj/aggcnpj_cnae95", nokeep
replace clas_cnae_95 = mod_clas_cnae_95 if clas_cnae_95==. | clas_cnae_95==-1
drop mod_clas_cnae_95 _merge

* merge aggregate sector and comparative advantage information
rename clas_cnae_95 cnae
sort cnae year
merge cnae year using "brazaux/intl/balassa-compadv-cnae", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _m wrld_exp wrld_tot braz_exp braz_tot balarank
rename balcadv cnae_balcadv

* merge additional sector information
replace cnae = int(cnae/10)
sort cnae year
merge cnae year using "brazrloc/auxil/sector-cnae-data", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
drop _m cnae_fdistk

* reset private-job share before 1995 to 1995
replace cnae_indprown_pis = cnae_indprown_pis_95 if cnae_indprown_pis==.
drop cnae_indprown_pis_95

// OCCUPATION VARIABLES

* outsourceable job share
sort cbogrp
merge cbogrp using "brazaux/auxil/cbogrp-outsourcing", nokeep
tab _m  // _m==1: CBO group missing
count if _m~=3 & cbogrp~=.
if `r(N)'>0  STOP  // incomplete CBO mapping
rename indoutsrc occ_indoutsrc
drop _m cbogrp

// PLANT VARIABLES

* merge RAIS information by plant
rename year ano
sort identificad ano
merge identificad ano using "brazrloc/data/rais-cnpj-data-metro", nokeep
tab _m  // _m==1: single worker firms will be omitted from regression with plant-level variables
drop _m
replace plant_n_pis = ln(plant_n_pis)
rename plant_n_pis plant_lnempl
label var plant_lnempl "Log Employment"

// FIRM VARIABLES

* switch to firm level (firm ID)
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"

* merge export status information by firm
sort cnpj_radic ano
merge cnpj_radic ano using "brazaux/secex/brazaux-exporters", nokeep
gen byte indexp = (_merge==3)
replace indexp = . if ano<1990 | ano>2001  // no SECEX information prior to 1990 or after 2001
label define indexp 0 "Nonexporter", modify
label define indexp 1 "Exporter", modify
label var indexp "Indic.: Exporter"
label values indexp indexp
drop _m
rename ano year
rename indexp firm_indexp

* merge PIA information
rename cnpj_radic firm
sort firm year
merge firm year using "brazrloc/data/pia-data"
tab _m
drop if _m==2
drop firm_lntfp firm_ln_cap_empl _m
iis, clear
tis, clear
tsset, clear
rename firm cnpj_radic

// WORKER VARIABLES

* education indicators
gen byte indprim = (grau_instr==1 | grau_instr==2 | grau_instr==3 | grau_instr==4 | grau_instr==5)
label var indprim "Primary or Middle School Educ."
gen byte indhigh = (grau_instr==6 | grau_instr==7)
label var indhigh "High School Education"
gen byte indscoll = (grau_instr==8)
label var indscoll "Some College Education"
gen byte indgrad = (grau_instr==9)
label var indgrad "Complete College Education"
drop grau_instr

* occupation indicators (based on 3-digit cbo; see rais/cbo/cbogrp2occagg.csv)
gen byte indprof = (occagg==1)
label var indprof "Professional or Managerial Occ."
gen byte indtech = (occagg==2)
label var indtech "Technical or Supervisory Occup."
gen byte indwhit = (occagg==3)
label var indwhit "Other White Collar Occupation"
gen byte indsklb = (occagg==4)
label var indsklb "Skilled Blue Collar Occupation"
gen byte indunsklb = (occagg==5)
label var indunsklb "Unskilled Blue Collar Occupation"
drop occagg

// ANNUAL VARIABLES

* exporting status instruments
sort year
merge year using "brazrloc/auxil/wtf-data", nokeep
count if _m~=3
if `r(N)' > 0  STOP  // years incomplete in wtf-data.dta
drop _m

// FINALIZE ESTIMATION SAMPLE

sort wid year mes_adm rem_media cnpj_radic
drop mes_adm rem_media

* interaction variables and dummies
gen cnae_balcadv_tarf = cnae_balcadv * cnae_tarfoutp
label var cnae_balcadv_tarf "cnae_balcadv * cnae_tarfoutp"
gen firm_indexp_tarf = firm_indexp * cnae_tarfoutp
label var firm_indexp_tarf "firm_indexp * cnae_tarfoutp"
gen cnae_balcadv_indexp = cnae_balcadv * firm_indexp
label var cnae_balcadv_indexp "cnae_balcadv * firm_indexp"
gen cnae_balcadv_indexp_tarf = cnae_balcadv * cnae_tarfoutp * firm_indexp
label var cnae_balcadv_indexp_tarf "cnae_balcad * _tarfout * _indexp"
qui tab year, generate(indyr_)
qui tab subs_ibge, generate(indsubs_) nolab
drop cnae subs_ibge

order wid year cnpj_radic indhire indexcl cnae_balcadv* cnae_fdiflw cnae_reffpen cnae_tarfoutp cnae_tarfintm cnae_herfsale cnae_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_indexp* firm_lnlp indprim indhigh indscoll indgrad indprof indtech indwhit indsklb indunsklb cnae_dollar cnae_ppieu cnae_ppinam
save "brazrloc/data/accessions-metromale-prime-cnae.dta", replace
}

else use "brazrloc/data/accessions-metromale-prime-cnae.dta", clear

// keep only first accession per year
drop if indexcl


* IV REGRESSIONS: FIRST STAGE

local rnd 0
foreach depvar in `endog' {
  local rnd = `rnd' + 1
  reg `depvar' cnae_balcadv `baseiv' `cntrlfrm' `cntrlwrk'
  * xtreg `depvar' cnae_balcadv `baseiv' `cntrlfrm' `cntrlwrk', fe i(cnpj_radic)
  if `rnd'==1  est2vec cnae_hire_iv1st, vars(cnae_balcadv cnae_balcadv_tarf firm_indexp firm_indexp_tarf cnae_tarfoutp cnae_tarfintm cnae_reffpen prd_cnae_tarfoutp res_cnae_tarfoutp prd_cnae_tarfintm res_cnae_tarfintm prd_cnae_reffpen res_cnae_reffpen prd_indexp res_indexp cnae_secrealx cnae_fdiflw cnae_herfsale cnae_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_lnlp indprof indtech indwhit indsklb indunsklb indprim indhigh indscoll indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indcnae_1 indcnae_2 indcnae_3 indcnae_4 indcnae_5 indcnae_6 indcnae_7 indcnae_8 indcnae_9 indcnae_10 indcnae_11 indcnae_12 indcnae_13 indcnae_14 indcnae_15 indcnae_16 indcnae_17 indcnae_18 indcnae_19 indcnae_20 indcnae_21 indcnae_22 indcnae_23 indcnae_24 indcnae_25 indcnae_26 cnae_dollar cnae_ppieu cnae_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) name(`depvar')
  else         est2vec cnae_hire_iv1st, addto(cnae_hire_iv1st) name(`depvar')
  test `baseiv'
  if `rnd'==1  est2vec cnae_hire_iv1st, r(F p df df_r) name(`depvar')
  else         est2vec cnae_hire_iv1st, raddto(cnae_hire_iv1st) name(`depvar')
  predict prd_`depvar', xb
  label var prd_`depvar' "OLS prediction: `depvar'"
  predict res_`depvar', residuals
  label var res_`depvar' "OLS residuals: `depvar'"
  }
reg firm_indexp cnae_balcadv `expiv' `cntrlfrm'
* xtreg firm_indexp cnae_balcadv `expiv' `cntrlfrm', fe i(cnpj_radic)
est2vec cnae_hire_iv1st, addto(cnae_hire_iv1st) name(firm_indexp)
test `expiv'
est2vec cnae_hire_iv1st, raddto(cnae_hire_iv1st) name(firm_indexp)
predict prd_indexp, xb
label var prd_indexp "OLS prediction: indexp"
predict res_indexp, residuals
label var res_indexp "OLS residuals: indexp"
preserve
  keep cnpj_radic year firm_indexp `focallst' `expiv' `cntrlfrm'
  sort cnpj_radic year
  by cnpj_radic year: keep if _n==1
  reg firm_indexp cnae_balcadv `expiv' `cntrlfrm'
  * xtreg firm_indexp cnae_balcadv `expiv' `cntrlfrm', fe i(cnpj_radic)
  est2vec cnae_hire_iv1st, addto(cnae_hire_iv1st) name(firm_indexp_frmlvl)
  test `expiv'
  est2vec cnae_hire_iv1st, raddto(cnae_hire_iv1st) name(firm_indexp_frmlvl)
  reg firm_indexp cnae_balcadv cnae_balcadv_tarf `expiv' `cntrlfrm'
  * xtreg firm_indexp cnae_balcadv cnae_balcadv_tarf `expiv' `cntrlfrm', fe i(cnpj_radic)
  est2vec cnae_hire_iv1st, addto(cnae_hire_iv1st) name(firm_indexp_frmlvl_all)
  test `expiv'
  est2vec cnae_hire_iv1st, raddto(cnae_hire_iv1st) name(firm_indexp_frmlvl_all)
restore
drop cnpj_radic


* REGRESSIONS

// main regression

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, vars(cnae_balcadv cnae_balcadv_tarf firm_indexp firm_indexp_tarf cnae_balcadv_indexp cnae_balcadv_indexp_tarf cnae_tarfoutp cnae_tarfintm cnae_reffpen prd_cnae_tarfoutp res_cnae_tarfoutp prd_cnae_tarfintm res_cnae_tarfintm prd_cnae_reffpen res_cnae_reffpen prd_indexp res_indexp cnae_secrealx cnae_fdiflw cnae_herfsale cnae_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_lnlp indprof indtech indwhit indsklb indunsklb indprim indhigh indscoll indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indcnae_1 indcnae_2 indcnae_3 indcnae_4 indcnae_5 indcnae_6 indcnae_7 indcnae_8 indcnae_9 indcnae_10 indcnae_11 indcnae_12 indcnae_13 indcnae_14 indcnae_15 indcnae_16 indcnae_17 indcnae_18 indcnae_19 indcnae_20 indcnae_21 indcnae_22 indcnae_23 indcnae_24 indcnae_25 indcnae_26 cnae_dollar cnae_ppieu cnae_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_focal)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

clogit indhire `focallst' `addlst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_all)

// comparisons with omitted focal variables

clogit indhire cnae_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_nointrct)

clogit indhire cnae_balcadv `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_balcadv)

clogit indhire cnae_balcadv cnae_balcadv_tarf `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_balcadv_tarf)

clogit indhire firm_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_indexp)

clogit indhire firm_indexp firm_indexp_tarf cnae_tarfoutp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_indexp_tarf)

clogit indhire cnae_tarfoutp cnae_tarfintm `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_aspme)

// xt comparison regressions

xtreg indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indsmpl, fe i(wid)
est2vec cnae_hire, addto(cnae_hire) name(xtreg_ifclogit)

xtreg indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, fe i(wid)
est2vec cnae_hire, addto(cnae_hire) name(xtreg)

xtreg indhire cnae_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, fe i(wid)
est2vec cnae_hire, addto(cnae_hire) name(xtreg_nointrct)

// logit comparison regressions

logit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indsmpl, robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(logit_focal_ifclogit)

logit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(logit_focal)

logit indhire cnae_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(logit_focal_nointrct)

// ols comparison regressions

reg indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indsmpl, cluster(wid)
est2vec cnae_hire, addto(cnae_hire) name(ols_ifclogit)

reg indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, cluster(wid)
est2vec cnae_hire, addto(cnae_hire) name(ols)

reg indhire cnae_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, cluster(wid)
est2vec cnae_hire, addto(cnae_hire) name(ols_nointrct)

// robustness checks

clogit indhire cnae_balcadv cnae_balcadv_tarf `endog' `cntrlfrm' `cntrlwrk' indyr*, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_allyrs)

clogit indhire `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_nofocal)

capture clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* indsubs* if year>=1990, group(wid) robust iterate(`maxiter')
if _rc==0  est2vec cnae_hire, addto(cnae_hire) name(clogit_indsubs)

clogit indhire `focallst' cnae_indprown_pis `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_indprown)

clogit indhire `focallst' occ_indoutsrc `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_indoutsrc)

clogit indhire `focallst' firm_lnlp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_lnlp)

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' `addlwrkr' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_addlwrkr)

// iv

clogit indhire cnae_balcadv firm_indexp prd_cnae_tarfoutp res_cnae_tarfoutp prd_cnae_tarfintm res_cnae_tarfintm prd_cnae_reffpen res_cnae_reffpen `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_iv_tarfetc)

clogit indhire cnae_balcadv prd_indexp res_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_iv_indexp)

clogit indhire cnae_balcadv prd_indexp res_indexp prd_cnae_tarfoutp res_cnae_tarfoutp prd_cnae_tarfintm res_cnae_tarfintm prd_cnae_reffpen res_cnae_reffpen `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_iv_all)

xtivreg indhire cnae_balcadv cnae_balcadv_tarf `cntrlfrm' `cntrlwrk' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, fe i(wid)
est2vec cnae_hire, addto(cnae_hire) name(xtivreg)

xtivreg indhire cnae_balcadv `cntrlfrm' `cntrlwrk' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, fe i(wid)
est2vec cnae_hire, addto(cnae_hire) name(xtivreg_nointrct)

ivreg indhire cnae_balcadv cnae_balcadv_tarf `cntrlfrm' `cntrlwrk' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, cluster(wid)
est2vec cnae_hire, addto(cnae_hire) name(olsiv)

ivreg indhire cnae_balcadv `cntrlfrm' `cntrlwrk' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, cluster(wid)
est2vec cnae_hire, addto(cnae_hire) name(olsiv_nointrct)

// education group cnaeamples

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indprim & year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_indprim)

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indhigh & year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_indhigh)

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indscoll | indgrad & year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnae_hire, addto(cnae_hire) name(clogit_indcoll)

// alternative accession definitions

* clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indexcl & year>=1990, group(wid) robust iterate(`maxiter')
* est2vec cnae_hire, addto(cnae_hire) name(clogit_firstjobs)  // sample of first jobs per year


* SAVE RESULTS

preserve
foreach type in b se e {
  matsave cnae_hire_`type', p(brazrloc/estmat/v4/reg/metromale-prime) t(double) replace dropall
  }
foreach type in b se e r {
  matsave cnae_hire_iv1st_`type', p(brazrloc/estmat/v4/reg/metromale-prime) t(double) replace dropall
  }
restore
drop prd_cnae_tarfoutp res_cnae_tarfoutp prd_cnae_tarfintm res_cnae_tarfintm prd_cnae_reffpen res_cnae_reffpen prd_indexp res_indexp indsmpl

log close

