version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/metromale-prime"

capture log close
log using "brazrloc/logs/labprodlvl-metromale-prime-subsibge.log", replace

local focallst "subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf"
local addlst   "subs_balcadv_indexp subs_balcadv_indexp_tarf"
local nberlst  "firm_indexp firm_indexp_tarf"
local cntrlsec "subs_secrealx subs_fdiflw subs_herfsale"
local cntrlwkf "plant_lnempl plant_tenuryr plant_indprof plant_indtech plant_indwhit plant_indsklb"
local addlwkf  "plant_indprim plant_indhigh" 
local endog    "subs_tarfoutp subs_tarfintm subs_reffpen"
local baseiv   "subs_dollar subs_ppieu subs_ppinam subs_ppioecd subs_ppiworld"  // note additional IVs subs_ppioecd subs_ppiworld (to keep expiv from iv list)
local expiv    "imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU"


* SUBSECTOR IBGE VARIABLES, EMPLOYERS OF BRAZILIAN PRIME-AGE MALES
*-----------------------------------------------------------------
* Years 1990-1998

use "brazrloc/data/employment-metromale-prime-subsibge.dta", clear
order identificad year firm_lnlp

* 20-percent pseudo-random sampling
* qui count
* local startid = int(`r(N)'/5)
* local endid = `startid'*2
* keep in `startid'/`endid'
* codebook identificad


* IV REGRESSIONS: FIRST STAGE

local rnd 0
foreach depvar in `endog' {
  local rnd = `rnd' + 1
  reg `depvar' subs_balcadv `baseiv' `cntrlsec' `cntrlwkf'
  * xtreg `depvar' subs_balcadv `baseiv' `cntrlsec' `cntrlwkf', fe /*cluster(identificad) robust*/
  if `rnd'==1  est2vec subs_lnlplvl_iv1st, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc firm_lnlp plant_lnempl plant_tenuryr plant_indprof plant_indtech plant_indwhit plant_indsklb plant_indunsklb plant_indprim plant_indhigh plant_indscoll plant_indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam subs_ppioecd subs_ppiworld imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) name(`depvar')
  else         est2vec subs_lnlplvl_iv1st, addto(subs_lnlplvl_iv1st) name(`depvar')
  test `baseiv'
  if `rnd'==1  est2vec subs_lnlplvl_iv1st, r(F p df df_r) name(`depvar')
  else         est2vec subs_lnlplvl_iv1st, raddto(subs_lnlplvl_iv1st) name(`depvar')
  predict prd_`depvar', xb
  label var prd_`depvar' "OLS prediction: `depvar'"
  predict res_`depvar', residuals
  label var res_`depvar' "OLS residuals: `depvar'"
  }
reg firm_indexp subs_balcadv `expiv' `cntrlsec'
* xtreg firm_indexp subs_balcadv `expiv' `cntrlsec', fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl_iv1st, addto(subs_lnlplvl_iv1st) name(firm_indexp_expiv)
test `expiv'
est2vec subs_lnlplvl_iv1st, raddto(subs_lnlplvl_iv1st) name(firm_indexp_expiv)
reg firm_indexp subs_balcadv `baseiv' `cntrlsec'
* xtreg firm_indexp subs_balcadv `baseiv' `cntrlsec', fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl_iv1st, addto(subs_lnlplvl_iv1st) name(firm_indexp_baseiv)
test `baseiv'
est2vec subs_lnlplvl_iv1st, raddto(subs_lnlplvl_iv1st) name(firm_indexp_baseiv)
predict prd_indexp, xb
label var prd_indexp "OLS baseiv prediction: indexp"
predict res_indexp, residuals
label var res_indexp "OLS baseiv residuals: indexp"
preserve
  keep identificad year firm_indexp `focallst' `expiv' `cntrlsec'
  sort identificad year
  by identificad year: keep if _n==1
  reg firm_indexp subs_balcadv `expiv' `cntrlsec'
  * xtreg firm_indexp subs_balcadv `expiv' `cntrlsec', fe /*cluster(identificad) robust*/
  est2vec subs_lnlplvl_iv1st, addto(subs_lnlplvl_iv1st) name(firm_indexp_frmlvl)
  test `expiv'
  est2vec subs_lnlplvl_iv1st, raddto(subs_lnlplvl_iv1st) name(firm_indexp_frmlvl)
  reg firm_indexp subs_balcadv subs_balcadv_tarf `expiv' `cntrlsec'
  * xtreg firm_indexp subs_balcadv subs_balcadv_tarf `expiv' `cntrlsec', fe /*cluster(identificad) robust*/
  est2vec subs_lnlplvl_iv1st, addto(subs_lnlplvl_iv1st) name(firm_indexp_frmlvl_all)
  test `expiv'
  est2vec subs_lnlplvl_iv1st, raddto(subs_lnlplvl_iv1st) name(firm_indexp_frmlvl_all)
restore


* REGRESSIONS

// main regression

xtreg firm_lnlp `focallst' `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc firm_lnlp plant_lnempl plant_tenuryr plant_indprof plant_indtech plant_indwhit plant_indsklb plant_indunsklb plant_indprim plant_indhigh plant_indscoll plant_indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam subs_ppioecd subs_ppiworld imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) e(N F p df_m r2 r2_o r2_w) name(xtreg_focal)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtreg sample"
tab year if indsmpl

xtreg firm_lnlp `focallst' `addlst' `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_all)

// nber main regression

xtreg firm_lnlp `nberlst' `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_nber_focal)

xtreg firm_lnlp `nberlst' `addlst' `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_nber_all)

// comparisons with omitted focal variables

xtreg firm_lnlp subs_balcadv firm_indexp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_nointrct)

xtreg firm_lnlp subs_balcadv `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_balcadv)

xtreg firm_lnlp subs_balcadv subs_balcadv_tarf subs_tarfoutp `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_balcadv_tarf)

xtreg firm_lnlp firm_indexp `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_indexp)

xtreg firm_lnlp firm_indexp firm_indexp_tarf subs_tarfoutp `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_indexp_tarf)

xtreg firm_lnlp subs_tarfoutp subs_tarfintm `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_tarf)

xtreg firm_lnlp subs_reffpen `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_reffpen)

// xt comparison regressions

xtreg firm_lnlp `focallst' `endog' `cntrlsec' `cntrlwkf' indyr* if indsmpl, fe /*cluster(identificad) robust*/  // different only if observations 1986-1989 loaded
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_ifxtreg)

xtreg firm_lnlp `focallst' `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg)

// ols comparison regressions

reg firm_lnlp `focallst' `endog' `cntrlsec' `cntrlwkf' indyr* if indsmpl, cluster(identificad)
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(ols_ifxtreg)

reg firm_lnlp `focallst' `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, cluster(identificad)
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(ols)

reg firm_lnlp subs_balcadv firm_indexp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, cluster(identificad)
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(ols_nointrct)

// robustness checks

xtreg firm_lnlp subs_balcadv subs_balcadv_tarf `endog' `cntrlsec' `cntrlwkf' indyr*, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_allyrs)

xtreg firm_lnlp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_nofocal)

xtreg firm_lnlp `focallst' `endog' `cntrlsec' `cntrlwkf' indyr* indsubs* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_indsubs)

xtreg firm_lnlp `focallst' subs_indprown_pis `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_indprown)

xtreg firm_lnlp `focallst' firm_lnlp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_firm_lnlp)

xtreg firm_lnlp `focallst' `endog' `cntrlsec' `cntrlwkf' `addlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_addlwkf)

// iv

xtreg firm_lnlp subs_balcadv firm_indexp prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_iv_tarfetc)

xtreg firm_lnlp subs_balcadv prd_indexp res_indexp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_iv_indexp)

xtreg firm_lnlp subs_balcadv prd_indexp res_indexp prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_iv_all)

xtivreg firm_lnlp subs_balcadv subs_balcadv_tarf `cntrlsec' `cntrlwkf' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtivreg)

xtivreg firm_lnlp subs_balcadv `cntrlsec' `cntrlwkf' indyr* (firm_indexp `endog' = `baseiv') if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtivreg_noexpiv)

xtivreg firm_lnlp subs_balcadv `cntrlsec' `cntrlwkf' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtivreg_nointrct)

// nber iv

xtreg firm_lnlp firm_indexp prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_nberiv_tarfetc)

xtreg firm_lnlp prd_indexp res_indexp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_nberiv_indexp)

xtreg firm_lnlp prd_indexp res_indexp prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtreg_nberiv_all)

xtivreg firm_lnlp `cntrlsec' `cntrlwkf' indyr* (firm_indexp firm_indexp_tarf `endog' = `baseiv' `expiv') if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtivreg_nber)

xtivreg firm_lnlp subs_tarfintm subs_reffpen `cntrlsec' `cntrlwkf' indyr* (firm_indexp firm_indexp_tarf subs_tarfoutp = `baseiv') if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtivreg_nber_noexpiv)

xtivreg firm_lnlp `cntrlsec' `cntrlwkf' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_lnlplvl, addto(subs_lnlplvl) name(xtivreg_nber_nointrct)


* SAVE RESULTS

preserve
foreach type in b se e {
  matsave subs_lnlplvl_`type', p(brazrloc/estmat/v4/reg/metromale-prime) t(double) replace dropall
  }
foreach type in b se e r {
  matsave subs_lnlplvl_iv1st_`type', p(brazrloc/estmat/v4/reg/metromale-prime) t(double) replace dropall
  }
restore
drop prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp indsmpl

log close

