clear
clear matrix
set mem 100m
set mat 800

capture mkdir "brazrloc/estmat/v4"
capture mkdir "brazrloc/estmat/v4/pme"

capture log close
log using "brazrloc/logs/pme-revision", replace

use "brazrloc/pme/pme-revision", clear
order year t48 tf tinf ticp subs_tarfoutp subs_tarfintm ntarout ntarint subs_secrealx subs_fdiflw subs_fdistk subs_reffpen subs_herfsale subs_indunsklb subs_indprown_pis exper* ded* dy* duf* dsec*
compress
label var year "Calendar year"
label var t48  "Work status trans. 4th-8th intv."
label var tf   "Formality 4 months prior"
label var tinf "Informality 4 months prior"
label var ticp "Inform./selfempl. 4 monhts prior"
local i 0
foreach uf in RJ SP RS MG PE BA {
  local i = `i' + 1
  label var duf`i' "`uf'"
  }
label var exper  "Labor-market experience"
label var exper2 "Labor-market experience squared"
label var ded2   "Education  8-11 yrs."
label var ded3   "Education 12-14 yrs."
label var ded4   "Education  >=15 yrs."
label var ntarint "Ann. Industry Intm. Input Tariff"
label var ntarout "Ann. Industry Output Tariff"
forvalues i = 2/13 {
  label var dsubs`i' "Subsector IBGE `i'"
  }
local i 1
forvalues yr = 88(2)98 {
  local i = `i' + 1
  label var dy`i' "Year 19`yr'"
  }
forvalues i = 1/20 {
  label var ind`i' "PME Industry `i'"
  }

* workforce categories
* F: formal; I: informal; CP: conta-pr�pria (self-employed); D: desempregado (unemployed); E empregador (employer); ForaPEA (out of labor force)
tab t48

* reduced workforce categories
gen byte t48redx = t48
replace t48redx =  2 if t48redx== 3  // join "to I-CP" in single category
replace t48redx =  7 if t48redx==13  // join "from I-CP" in single category
replace t48redx =  8 if t48redx==14 | t48redx==9 | t48redx==15 // join "from I-CP" in single category
replace t48redx = 10 if t48redx==16  // join "from I-CP" in single category
replace t48redx = 11 if t48redx==17  // join "from I-CP" in single category
replace t48redx = 12 if t48redx==18  // join "from I-CP" in single category
label define ccddrdx 1 "F_F" 2 "F_ICP" 4 "F_D" 5 "F_ForaPEA" 6 "F_E" 7 "ICP_F" 8 "ICP_ICP" 10 "ICP_D" 11 "ICP_ForaPEA" 12 "ICP_E"
label values t48redx ccddrdx
tab t48redx

* remove employer category
drop if t48==6 | t48==12 | t48==18

* remove unnecessary variables
drop nt* ind*

// from formality to ...

* regressor list
local varlist "tf subs_tarfoutp subs_tarfintm subs_secrealx subs_fdiflw subs_fdistk subs_reffpen subs_herfsale subs_indunsklb subs_indprown_pis exper exper2 ded1 ded2 ded3 ded4 dy1 dy2 dy3 dy4 dy5 dy6 dy7 duf1 duf2 duf3 duf4 duf5 duf6 dsec1 dsec2 dsec3 dsec4 dsec5 dsec6 dsubs2 dsubs3 dsubs4 dsubs5 dsubs6 dsubs7 dsubs8 dsubs9 dsubs10 dsubs11 dsubs12 dsubs13"
local varle : list sizeof varlist
tokenize `varlist'
local eqlist ""
foreach eq in F_I F_CP F_D F_ForaPEA {
  forvalues i = 1/`varle' {
    local eqlist "`eqlist' `eq':``i''"
    }
  }
* disp "`eqlist'"

* main regression with sector-fixed effects
mlogit t48 tf subs_tarfoutp subs_tarfintm exper* ded2-ded4 duf1 duf3-duf6 dy2-dy7 dsubs2-dsubs12
est2vec mlogit_tf, e(N r2_p chi2 df_m) name(main_secfe) vars(`eqlist')

* main regression without sector-fixed effects
mlogit t48 tf subs_tarfoutp subs_tarfintm exper* ded2-ded4 duf1 duf3-duf6 dy2-dy7
est2vec mlogit_tf, addto(mlogit_tf) name(main)

* replication with aggregate sector fixed effect
mlogit t48 tf subs_tarfoutp subs_tarfintm exper* ded2-ded4 duf1 duf3-duf6 dy2-dy7 dsec2-dsec6
est2vec mlogit_tf, addto(mlogit_tf) name(main_aggsecfe)

* full set of regressors, sector fixed effects
mlogit t48 tf subs_tarfoutp subs_tarfintm subs_reffpen subs_secrealx subs_fdiflw subs_fdistk subs_herfsale subs_indunsklb subs_indprown_pis exper* ded2-ded4 duf1 duf3-duf6 dy2-dy7 dsubs3-dsubs13
est2vec mlogit_tf, addto(mlogit_tf) name(fullspec_secfe)

* full set of regressors, no sector fixed effects
mlogit t48 tf subs_tarfoutp subs_tarfintm subs_reffpen subs_secrealx subs_fdiflw subs_fdistk subs_herfsale subs_indunsklb subs_indprown_pis exper* ded2-ded4 duf1 duf3-duf6 dy2-dy7
est2vec mlogit_tf, addto(mlogit_tf) name(fullspec_nosecfe)

* t48-redux and fine sector fixed effect
mlogit t48redx tf subs_tarfoutp subs_tarfintm exper* ded2-ded4 duf1 duf3-duf6 dy2-dy7 dsubs3-dsubs13
* est2vec mlogit_tf, addto(mlogit_tf) name(redx_secfe)


// from informality to ...

* regressor list
local varlist "tinf subs_tarfoutp subs_tarfintm subs_secrealx subs_fdiflw subs_fdistk subs_reffpen subs_herfsale subs_indunsklb subs_indprown_pis exper exper2 ded1 ded2 ded3 ded4 dy1 dy2 dy3 dy4 dy5 dy6 dy7 duf1 duf2 duf3 duf4 duf5 duf6 dsec1 dsec2 dsec3 dsec4 dsec5 dsec6 dsubs2 dsubs3 dsubs4 dsubs5 dsubs6 dsubs7 dsubs8 dsubs9 dsubs10 dsubs11 dsubs12 dsubs13"
local varle : list sizeof varlist
tokenize `varlist'
local eqlist ""
foreach eq in I_F I_CP I_D I_ForaPEA {
  forvalues i = 1/`varle' {
    local eqlist "`eqlist' `eq':``i''"
    }
  }
* disp "`eqlist'"

* main regression with sector-fixed effects
mlogit t48 tinf subs_tarfoutp subs_tarfintm exper* ded2-ded4 duf1 duf3-duf6 dy2-dy7 dsubs2-dsubs12
est2vec mlogit_tinf, e(N r2_p chi2 df_m) name(main_secfe) vars(`eqlist')

* main regression without sector-fixed effects
mlogit t48 tinf subs_tarfoutp subs_tarfintm exper* ded2-ded4 duf1 duf3-duf6 dy2-dy7
est2vec mlogit_tinf, addto(mlogit_tinf) name(main)

* replication with aggregate sector fixed effect
mlogit t48 tinf subs_tarfoutp subs_tarfintm exper* ded2-ded4 duf1 duf3-duf6 dy2-dy7 dsec2-dsec6
est2vec mlogit_tinf, addto(mlogit_tinf) name(main_aggsecfe)

* full set of regressors, sector fixed effects
mlogit t48 tinf subs_tarfoutp subs_tarfintm subs_reffpen subs_secrealx subs_fdiflw subs_fdistk subs_herfsale subs_indunsklb subs_indprown_pis exper* ded2-ded4 duf1 duf3-duf6 dy2-dy7 dsubs3-dsubs13
est2vec mlogit_tinf, addto(mlogit_tinf) name(fullspec_secfe)

* full set of regressors, no sector fixed effects
mlogit t48 tinf subs_tarfoutp subs_tarfintm subs_reffpen subs_secrealx subs_fdiflw subs_fdistk subs_herfsale subs_indunsklb subs_indprown_pis exper* ded2-ded4 duf1 duf3-duf6 dy2-dy7
est2vec mlogit_tinf, addto(mlogit_tinf) name(fullspec_nosecfe)

* t48-redux and fine sector fixed effect
mlogit t48redx ticp subs_tarfoutp subs_tarfintm exper* ded2-ded4 duf1 duf3-duf6 dy2-dy7 dsubs3-dsubs13
* est2vec mlogit_tinf, addto(mlogit_tinf) name(redx_secfe)


// matrix output
foreach type in b se e {
  matsave mlogit_tf_`type', p(brazrloc/estmat/v4/pme) replace dropall
  matsave mlogit_tinf_`type', p(brazrloc/estmat/v4/pme) replace dropall
  }


log close
