version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl-maleprime"

capture log close
log using "brazrloc/logs/separations-accessions-natl-maleprime-subsibge-cluster.log", replace

local maxiter $maxiter

local focallst "subs_balcadv firm_indexp"
local addlst   "subs_balcadv_tarf firm_indexp_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf"
local cntrlfrm "subs_secrealx subs_fdiflw subs_herfsale plant_lnempl plant_indprim plant_indhigh plant_indwhittot"
local addlwrkr "indhigh indscoll indgrad" 
local endog    "subs_tarfoutp subs_tarfintm subs_reffpen"
local baseiv   "subs_dollar subs_ppieu subs_ppinam"
local expiv    "imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU"


* SUBSECTOR IBGE VARIABLES, BRAZILIAN PRIME-AGE MALES
*----------------------------------------------------

* SEPARATION REGRESSIONS WITH CLUSTERING AT SECTOR LEVEL

local cntrlwrk "tenuryr potexper indprof indtech indwhit indsklb"
use "brazrloc/data/separations-natl-maleprime-subsibge.dta", clear

// obtain sector IDs from dummies
gen byte subs_ibge = .
label var subs_ibge "Subsector IBGE"
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge

// keep only last separation per year
drop if indexcl

// main regression

clogit inddspl `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
* est2vec subs_berman, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_lnlp tenuryr tenr2 potexper potxper2 indprof indtech indwhit indsklb indunsklb indprim indhigh indscoll indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_focal)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

capture noisily clogit inddspl `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter') cluster(subs_ibge)
* est2vec subs_berman, addto(subs_berman) name(clogit_focal_cluster)

// xt comparison regressions

xtreg inddspl `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, fe i(wid) cluster(subs_ibge)
* est2vec subs_berman, addto(subs_berman) name(xtreg_cluster_subs)

xtreg inddspl `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* indsubs* if year>=1990, fe i(wid) cluster(subs_ibge)
* est2vec subs_berman, addto(subs_berman) name(xtreg_cluster_subsfe)


* ACCESSION REGRESSIONS WITH CLUSTERING AT SECTOR LEVEL

local cntrlwrk "potexper indprof indtech indwhit indsklb"
use "brazrloc/data/accessions-natl-maleprime-subsibge.dta", clear

// obtain sector IDs from dummies
gen byte subs_ibge = .
label var subs_ibge "Subsector IBGE"
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge

// keep only first accession per year
drop if indexcl

// main regression

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
* est2vec subs_hire, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_lnlp indprof indtech indwhit indsklb indunsklb indprim indhigh indscoll indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_focal)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

capture noisily clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter') cluster(subs_ibge)
* est2vec subs_berman, addto(subs_berman) name(clogit_focal_cluster)

// xt comparison regressions

xtreg indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, fe i(wid) cluster(subs_ibge)
* est2vec subs_berman, addto(subs_berman) name(xtreg_cluster_subs)

xtreg indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* indsubs* if year>=1990, fe i(wid) cluster(subs_ibge)
* est2vec subs_berman, addto(subs_berman) name(xtreg_cluster_subsfe)

log close

