version 8.2
clear
set logtype text
set more off
set matsize 800

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl10pct"

capture log close
log using "brazrloc/logs/summary-stats-aerrr-natl10pct.log", replace

local maxiter $maxiter


// FIRST DIFFERENCE IN LOG PRODUCTIVITY

tempfile dlnlp
use firm year firm_lnlp using "brazrloc/data/pia-data.dta", clear
tsset firm year
gen firm_fdlnlp = F.firm_lnlp - firm_lnlp
label var firm_fdlnlp "Lead Log LP less Log LP"
drop firm_lnlp
rename firm cnpj_radic
compress
sort cnpj_radic year
save `dlnlp'

// AUXILIARY ANNUAL DATA

tempfile auxdat
insheet using "brazrloc/auxil/origs/pib.csv", clear
keep ano populacao pib_corrente_usd
rename ano year
label var year "Calendar Year"
rename populacao population
label var population "Population [mio]"
rename pib_corrente_usd gdp_usd
replace gdp_usd = gdp_usd/1000000
label var gdp_usd "GDP [current USD bio]"
keep if year>=1986 & year<=1998
sort year
merge year using "brazrloc/auxil/globfin-annual", nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m
keep year __brl_d population _ibx50d
sort year
save `auxdat'


// SUBSIBGE REGRESSIONS

local basendog "cnae_tarfoutp cnae_tarfintm"  // cut: cnae_reffpen
local basendog2 "cnae_tarfoutp cnae_tarfintm firm_indexp"  // cut: cnae_reffpen
local secexog  "subs_balcadv"
local secexo90 "subs_balcadv_90"
local secalt90 "subs_volrcadv_90"
local exoglst  "firm_indexp cnae_secrealx cnae_fdiflw cnae_herfsale"
local exoglst2 "cnae_secrealx cnae_fdiflw cnae_herfsale"
local cntrlfrm "plant_lnempl plant_indhigh plant_indcoll plant_indwhittot"
local ivlst    "cnae_ppieu cnae_ppinam imp_APD imp_CEE imp_NAM imp_OIN imp_WEU"
local intract1 "cnae_tarfoutp_indexp cnae_tarfintm_indexp"
local intract2 "cnae_tarfoutp_balcadv cnae_tarfintm_balcadv"
local intract2_90  "cnae_tarfoutp_balcadv_90 cnae_tarfintm_balcadv_90"
local intract3 "cnae_tarfoutp_indexp_balcadv cnae_tarfintm_indexp_balcadv"
local intract3_90  "cnae_tarfoutp_indexp_balcadv_90 cnae_tarfintm_indexp_balcadv_90"
local intract4 "cnae_tarfoutp_notindprim cnae_tarfintm_notindprim"  // if ~indprim
local intract5 "cnae_tarfoutp_indyoung cnae_tarfintm_indyoung"  // if potexper < 10
local intract6 "cnae_tarfoutp_indwhite cnae_tarfintm_indwhite"  // if indprof | indtech | indwhit
local intract7 "cnae_tarfoutp_indfemal cnae_tarfintm_indfemal"  // if indfemal
local intract8 "cnae_tarfoutp_notindprim cnae_tarfintm_notindprim firm_indexp_notindprim subs_balcadv_notindprim"
local intract9 "cnae_tarfoutp_indexp_notindprim cnae_tarfoutp_balcadv_notindprim cnae_tarfintm_indexp_notindprim cnae_tarfintm_balcadv_notindprim"
local intracta "cnae_tarfoutp_fdlnlp cnae_tarfintm_fdlnlp"
local intractb "firm_indexp_fdlnlp"
local intractc "cnae_tarfoutp_indexp_fdlnlp cnae_tarfintm_indexp_fdlnlp"
local addlreg  "cnae_indprown_pis occ_indoutsrc"
local auxyr    "__brl_d population _ibx50d"


* separations natl

local cntrlwrk "tenuryr tenuryr2 potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/separations-natl-subsibge-10pct.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }
gen tenuryr2 = tenuryr * tenuryr
label var tenuryr2 "Squared Tenure at plant (sq. yrs.)"
gen potexper2 = potexper * potexper
label var potexper2 "Squared Pot. labor force exp."
sort cnpj_radic year
merge cnpj_radic year using `dlnlp', nokeep
tab _m
drop _m 
order wid year cnpj_radic inddspl indlayoff indquit subs_balcadv subs_fdiflw subs_reffpen subs_tarfoutp subs_tarfintm subs_herfsale subs_indprown_pis occ_* plant_* firm_* firm_fdlnlp tenuryr tenuryr2 potexper potexper2 indprim indhigh indscoll indgrad indprof indtech indwhit indsklb indunsklb indfemal subs_dollar subs_ppieu subs_ppinam subs_secrealx imp_* indyr_* indsubs_*

* merge additional sector information
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/sector-subsibge-data", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
count if _m~=3
if `r(N)'>0  STOP  // incomplete sector-year mapping
drop _m subs_fdistk subs_indunsklb
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _merge wrld_exp wrld_tot braz_exp braz_tot balcadv
rename subsibge subs_ibge

* update sector information with CNAE in 1994-2001 (563 industries), keep subsibge information for 1986-1993 (26 sectors)
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta", keep(mod_clas_cnae_95) nokeep
drop _m
rename ano year
rename mod_clas_cnae_95 cnae
replace cnae=. if cnae==-1 | cnae==0
replace cnae=int(cnae/10)
sort cnae year
merge cnae year using "brazrloc/auxil/sector-cnae-data.dta", nokeep  // CNAE sector information in 1994-2001
foreach var in secrealx fdiflw reffpen tarfoutp tarfintm herfsale indprown_pis indprown_pis_95 dollar ppieu ppinam {
  replace cnae_`var' = subs_`var' if year<=1993  // keep subsibge information for 1986-1993
  drop subs_`var'
  }
gen long cnaemix = cnae // CNAE sector information in 1994-2001
replace cnaemix = subs_ibge if year<=1993  // keep subsibge information for 1986-1993
drop _m
* codebook subs_ibge cnae

* obtain sector information for niv50 when possible (PIA firms)
* sort cnpj_radic year
* merge cnpj_radic year using "brazrloc/data/pia-niv50.dta", nokeep
* tab _m
* count if niv50==. & firm_lnlp~=.
* count if niv50~=. & firm_lnlp==.
* drop _m
* codebook niv50

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain alternative revealed comparative-advantage measure
* rename subs_ibge subsibge
* sort subsibge year
* merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
* qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
* if `r(N)'>0  STOP
* drop _m
* rename subsibge subs_ibge
* rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* auxiliary annual data
sort year
merge year using `auxdat', nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv {  // subs_volrcadv
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
* label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"

* interactions
gen cnae_tarfoutp_indexp = cnae_tarfoutp * firm_indexp
label var cnae_tarfoutp_indexp "tarfoutp * indexp"
gen cnae_tarfintm_indexp = cnae_tarfintm * firm_indexp
label var cnae_tarfintm_indexp "tarfintm * indexp"
gen cnae_tarfoutp_balcadv = cnae_tarfoutp * subs_balcadv
label var cnae_tarfoutp_balcadv "tarfoutp * balcadv"
gen cnae_tarfintm_balcadv = cnae_tarfintm * subs_balcadv
label var cnae_tarfintm_balcadv "tarfintm * balcadv"
gen cnae_tarfoutp_indexp_balcadv = cnae_tarfoutp * firm_indexp * subs_balcadv
label var cnae_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen cnae_tarfintm_indexp_balcadv = cnae_tarfintm * firm_indexp * subs_balcadv
label var cnae_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen cnae_tarfoutp_fdlnlp = cnae_tarfoutp * firm_fdlnlp
label var cnae_tarfoutp_fdlnlp "tarfoutp * firm_fdlnlp"
gen cnae_tarfintm_fdlnlp = cnae_tarfintm * firm_fdlnlp
label var cnae_tarfintm_fdlnlp "tarfintm * firm_fdlnlp"
gen firm_indexp_fdlnlp = firm_indexp * firm_fdlnlp
label var firm_indexp_fdlnlp "firm_indexp * firm_fdlnlp"
gen cnae_tarfoutp_indexp_fdlnlp = cnae_tarfoutp * firm_indexp * firm_fdlnlp
label var cnae_tarfoutp_indexp_fdlnlp "tarfoutp * indexp * fdlnlp"
gen cnae_tarfintm_indexp_fdlnlp = cnae_tarfintm * firm_indexp * firm_fdlnlp
label var cnae_tarfintm_indexp_fdlnlp "tarfintm * indexp * fdlnlp"
gen cnae_tarfoutp_notindprim = cnae_tarfoutp * (~indprim) // if ~indprim
label var cnae_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen cnae_tarfintm_notindprim = cnae_tarfintm * (~indprim) // if ~indprim
label var cnae_tarfintm_notindprim "tarfintm * (~indprim)"
gen cnae_tarfoutp_indyoung = cnae_tarfoutp * (potexper<10) // if potexper < 10
label var cnae_tarfoutp_indyoung "cnae_tarfoutp * (potexper<10)"
gen cnae_tarfintm_indyoung = cnae_tarfintm * (potexper<10) // if potexper < 10
label var cnae_tarfintm_indyoung "cnae_tarfintm * (potexper<10)"
gen cnae_tarfoutp_indwhite = cnae_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var cnae_tarfoutp_indwhite "cnae_tarfoutp * (indwhit+)"
gen cnae_tarfintm_indwhite = cnae_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var cnae_tarfintm_indwhite "cnae_tarfintm * (indwhit+)"
gen cnae_tarfoutp_indfemal = cnae_tarfoutp * (indfemal) // if indfemal
label var cnae_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen cnae_tarfintm_indfemal = cnae_tarfintm * (indfemal) // if indfemal
label var cnae_tarfintm_indfemal "tarfintm * (indfemal)"
gen cnae_tarfoutp_balcadv_90 = cnae_tarfoutp * subs_balcadv_90
label var cnae_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen cnae_tarfintm_balcadv_90 = cnae_tarfintm * subs_balcadv_90
label var cnae_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen cnae_tarfoutp_indexp_balcadv_90 = cnae_tarfoutp * firm_indexp * subs_balcadv_90
label var cnae_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen cnae_tarfintm_indexp_balcadv_90 = cnae_tarfintm * firm_indexp * subs_balcadv_90
label var cnae_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"
* gen cnae_tarfoutp_volrcadv_90 = cnae_tarfoutp * subs_volrcadv_90
* label var cnae_tarfoutp_volrcadv_90 "tarfoutp * volrcadv_90"
* gen cnae_tarfintm_volrcadv_90 = cnae_tarfintm * subs_volrcadv_90
* label var cnae_tarfintm_volrcadv_90 "tarfintm * volrcadv_90"
* gen cnae_tarfoutp_indexp_volrcadv_90 = cnae_tarfoutp * firm_indexp * subs_volrcadv_90
* label var cnae_tarfoutp_indexp_volrcadv_90 "tarfoutp * indexp * volrcadv_90"
* gen cnae_tarfintm_indexp_volrcadv_90 = cnae_tarfintm * firm_indexp * subs_volrcadv_90
* label var cnae_tarfintm_indexp_volrcadv_90 "tarfintm * indexp * volrcadv_90"
gen subs_balcadv_up = subs_balcadv * (subs_balcadv >= subs_balcadv_90)
label var subs_balcadv_up "subs_balcadv if >= subs_balcadv_90"
gen subs_balcadv_dn = subs_balcadv * (subs_balcadv < subs_balcadv_90)
label var subs_balcadv_dn "subs_balcadv if < subs_balcadv_90"

* sector dummies at CNAE-mix level, trim data to main period, main variables and non-missing observations 
keep if year>=1990  // if condition in all regressions 
keep if cnae_tarfoutp~=. & cnae_tarfintm~=. & firm_indexp~=.  // basendog 
keep wid cnpj_radic year cnaemix inddspl indlayoff indquit `basendog' firm_lnlp firm_fdlnlp `secexo90' `exoglst' `cntrlfrm' `cntrlwrk' `ivlst' `intracta' `intractb' `intractc' `intract1' `intract4' `intract5' `intract6' `intract7' cnae_indprown_pis occ_indoutsrc indyr* trd_indsubs* balarank
qui tab cnaemix, generate(indcnaem_)


xtreg inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indcnaem* indyr* if year>=1990, fe i(wid)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtreg sample"
tab year if indsmpl

summ cnae_tarfoutp cnae_tarfintm firm_indexp if year==1990 & indsmpl
summ cnae_tarfoutp cnae_tarfintm firm_indexp if year==1992 & indsmpl
summ cnae_tarfoutp cnae_tarfintm firm_indexp if year==1994 & indsmpl
summ cnae_tarfoutp cnae_tarfintm firm_indexp if year==1997 & indsmpl
summ cnae_tarfoutp cnae_tarfintm firm_indexp if year==1998 & indsmpl

summ2tex * if indsmpl, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl10pct) name(summ_dspl_aerrr_allsec) replace detail
summ2tex * if indsmpl & balarank==1, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl10pct) name(summ_dspl_aerrr_balrnk1) replace detail
summ2tex * if indsmpl & balarank==3, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl10pct) name(summ_dspl_aerrr_balrnk3) replace detail
summ2tex * if indsmpl & balarank==5, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl10pct) name(summ_dspl_aerrr_balrnk5) replace detail
summ2tex * if indsmpl & firm_indexp, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl10pct) name(summ_dspl_aerrr_indexp) replace detail

preserve
mat summ_dspl_aerrr_timevar_tbl = J(8,4,.)
mat rownames summ_dspl_aerrr_timevar_tbl = plant_lnempl:1990 plant_lnempl:1992 plant_lnempl:1994 plant_lnempl:1998 firm_lnlp:1990 firm_lnlp:1992 firm_lnlp:1994 firm_lnlp:1998
mat colnames summ_dspl_aerrr_timevar_tbl = mean:allsec sd:allsec mean:balarank5 mean:firm_indexp
foreach var in plant_lnempl firm_lnlp {
  foreach yr in 90 92 94 98 {
    qui summ `var' if year==19`yr'
    mat summ_dspl_aerrr_timevar_tbl[rownumb(summ_dspl_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_dspl_aerrr_timevar_tbl,"mean:allsec")] = `r(mean)'
    mat summ_dspl_aerrr_timevar_tbl[rownumb(summ_dspl_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_dspl_aerrr_timevar_tbl,"sd:allsec")] = `r(sd)'
    qui summ `var' if year==19`yr' & balarank==5, meanonly
    mat summ_dspl_aerrr_timevar_tbl[rownumb(summ_dspl_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_dspl_aerrr_timevar_tbl,"mean:balarank5")] = `r(mean)'
    qui summ `var' if year==19`yr' & firm_indexp, meanonly
    mat summ_dspl_aerrr_timevar_tbl[rownumb(summ_dspl_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_dspl_aerrr_timevar_tbl,"mean:firm_indexp")] = `r(mean)'
    }
  }
est2tex summ_dspl_aerrr_timevar, ready dropall path(brazrloc/estmat/v4/reg/natl10pct) replace
restore

keep cnpj_radic year firm_indexp balarank indsmpl
bysort cnpj_radic year indsmpl: keep if _n==1
collapse (sum) firm_indexp if indsmpl, by(balarank year) fast
list


* accessions natl

local cntrlwrk "potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/accessions-natl-subsibge-10pct.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }
gen potexper2 = potexper * potexper
label var potexper2 "Squared Pot. labor force exp."
sort cnpj_radic year
merge cnpj_radic year using `dlnlp', nokeep
tab _m
drop _m 
order wid year cnpj_radic indhire subs_balcadv subs_fdiflw subs_reffpen subs_tarfoutp subs_tarfintm subs_herfsale subs_indprown_pis occ_* plant_* firm_* firm_fdlnlp potexper potexper2 indprim indhigh indscoll indgrad indprof indtech indwhit indsklb indunsklb indfemal subs_dollar subs_ppieu subs_ppinam subs_secrealx imp_* indyr_* indsubs_*

* merge additional sector information
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/sector-subsibge-data", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
count if _m~=3
if `r(N)'>0  STOP  // incomplete sector-year mapping
drop _m subs_fdistk subs_indunsklb
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _merge wrld_exp wrld_tot braz_exp braz_tot balcadv
rename subsibge subs_ibge

* update sector information with CNAE in 1994-2001 (563 industries), keep subsibge information for 1986-1993 (26 sectors)
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta", keep(mod_clas_cnae_95) nokeep
drop _m
rename ano year
rename mod_clas_cnae_95 cnae
replace cnae=. if cnae==-1 | cnae==0
replace cnae=int(cnae/10)
sort cnae year
merge cnae year using "brazrloc/auxil/sector-cnae-data.dta", nokeep  // CNAE sector information in 1994-2001
foreach var in secrealx fdiflw reffpen tarfoutp tarfintm herfsale indprown_pis indprown_pis_95 dollar ppieu ppinam {
  replace cnae_`var' = subs_`var' if year<=1993  // keep subsibge information for 1986-1993
  drop subs_`var'
  }
gen long cnaemix = cnae // CNAE sector information in 1994-2001
replace cnaemix = subs_ibge if year<=1993  // keep subsibge information for 1986-1993
drop _m
* codebook subs_ibge cnae

* obtain sector information for niv50 when possible (PIA firms)
* sort cnpj_radic year
* merge cnpj_radic year using "brazrloc/data/pia-niv50.dta", nokeep
* tab _m
* count if niv50==. & firm_lnlp~=.
* count if niv50~=. & firm_lnlp==.
* drop _m
* codebook niv50

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain alternative revealed comparative-advantage measure
* rename subs_ibge subsibge
* sort subsibge year
* merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
* qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
* if `r(N)'>0  STOP
* drop _m
* rename subsibge subs_ibge
* rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* auxiliary annual data
sort year
merge year using `auxdat', nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv { // subs_volrcadv
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
* label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"

* interactions
gen cnae_tarfoutp_indexp = cnae_tarfoutp * firm_indexp
label var cnae_tarfoutp_indexp "tarfoutp * indexp"
gen cnae_tarfintm_indexp = cnae_tarfintm * firm_indexp
label var cnae_tarfintm_indexp "tarfintm * indexp"
gen cnae_tarfoutp_balcadv = cnae_tarfoutp * subs_balcadv
label var cnae_tarfoutp_balcadv "tarfoutp * balcadv"
gen cnae_tarfintm_balcadv = cnae_tarfintm * subs_balcadv
label var cnae_tarfintm_balcadv "tarfintm * balcadv"
gen cnae_tarfoutp_indexp_balcadv = cnae_tarfoutp * firm_indexp * subs_balcadv
label var cnae_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen cnae_tarfintm_indexp_balcadv = cnae_tarfintm * firm_indexp * subs_balcadv
label var cnae_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen cnae_tarfoutp_fdlnlp = cnae_tarfoutp * firm_fdlnlp
label var cnae_tarfoutp_fdlnlp "tarfoutp * firm_fdlnlp"
gen cnae_tarfintm_fdlnlp = cnae_tarfintm * firm_fdlnlp
label var cnae_tarfintm_fdlnlp "tarfintm * firm_fdlnlp"
gen firm_indexp_fdlnlp = firm_indexp * firm_fdlnlp
label var firm_indexp_fdlnlp "firm_indexp * firm_fdlnlp"
gen cnae_tarfoutp_indexp_fdlnlp = cnae_tarfoutp * firm_indexp * firm_fdlnlp
label var cnae_tarfoutp_indexp_fdlnlp "tarfoutp * indexp * fdlnlp"
gen cnae_tarfintm_indexp_fdlnlp = cnae_tarfintm * firm_indexp * firm_fdlnlp
gen cnae_tarfoutp_notindprim = cnae_tarfoutp * (~indprim) // if ~indprim
label var cnae_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen cnae_tarfintm_notindprim = cnae_tarfintm * (~indprim) // if ~indprim
label var cnae_tarfintm_notindprim "tarfintm * (~indprim)"
gen cnae_tarfoutp_indyoung = cnae_tarfoutp * (potexper<10) // if potexper < 10
label var cnae_tarfoutp_indyoung "cnae_tarfoutp * (potexper<10)"
gen cnae_tarfintm_indyoung = cnae_tarfintm * (potexper<10) // if potexper < 10
label var cnae_tarfintm_indyoung "cnae_tarfintm * (potexper<10)"
gen cnae_tarfoutp_indwhite = cnae_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var cnae_tarfoutp_indwhite "cnae_tarfoutp * (indwhit+)"
gen cnae_tarfintm_indwhite = cnae_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var cnae_tarfintm_indwhite "cnae_tarfintm * (indwhit+)"
gen cnae_tarfoutp_indfemal = cnae_tarfoutp * (indfemal) // if indfemal
label var cnae_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen cnae_tarfintm_indfemal = cnae_tarfintm * (indfemal) // if indfemal
label var cnae_tarfintm_indfemal "tarfintm * (indfemal)"
gen cnae_tarfoutp_balcadv_90 = cnae_tarfoutp * subs_balcadv_90
label var cnae_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen cnae_tarfintm_balcadv_90 = cnae_tarfintm * subs_balcadv_90
label var cnae_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen cnae_tarfoutp_indexp_balcadv_90 = cnae_tarfoutp * firm_indexp * subs_balcadv_90
label var cnae_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen cnae_tarfintm_indexp_balcadv_90 = cnae_tarfintm * firm_indexp * subs_balcadv_90
label var cnae_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"
* gen cnae_tarfoutp_volrcadv_90 = cnae_tarfoutp * subs_volrcadv_90
* label var cnae_tarfoutp_volrcadv_90 "tarfoutp * volrcadv_90"
* gen cnae_tarfintm_volrcadv_90 = cnae_tarfintm * subs_volrcadv_90
* label var cnae_tarfintm_volrcadv_90 "tarfintm * volrcadv_90"
* gen cnae_tarfoutp_indexp_volrcadv_90 = cnae_tarfoutp * firm_indexp * subs_volrcadv_90
* label var cnae_tarfoutp_indexp_volrcadv_90 "tarfoutp * indexp * volrcadv_90"
* gen cnae_tarfintm_indexp_volrcadv_90 = cnae_tarfintm * firm_indexp * subs_volrcadv_90
* label var cnae_tarfintm_indexp_volrcadv_90 "tarfintm * indexp * volrcadv_90"
gen subs_balcadv_up = subs_balcadv * (subs_balcadv >= subs_balcadv_90)
label var subs_balcadv_up "subs_balcadv if >= subs_balcadv_90"
gen subs_balcadv_dn = subs_balcadv * (subs_balcadv < subs_balcadv_90)
label var subs_balcadv_dn "subs_balcadv if < subs_balcadv_90"

* sector dummies at CNAE-mix level, trim data to main period, main variables and non-missing observations 
keep if year>=1990  // if condition in all regressions 
keep if cnae_tarfoutp~=. & cnae_tarfintm~=. & firm_indexp~=.  // basendog 
keep wid cnpj_radic year cnaemix indhire `basendog' firm_lnlp firm_fdlnlp `secexo90' `exoglst' `cntrlfrm' `cntrlwrk' `ivlst' `intracta' `intractb' `intractc' `intract1' `intract4' `intract5' `intract6' `intract7' cnae_indprown_pis occ_indoutsrc indyr* trd_indsubs* balarank
qui tab cnaemix, generate(indcnaem_)


xtreg indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indcnaem* indyr* if year>=1990, fe i(wid)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtreg sample"
tab year if indsmpl

summ cnae_tarfoutp cnae_tarfintm firm_indexp if year==1990 & indsmpl
summ cnae_tarfoutp cnae_tarfintm firm_indexp if year==1992 & indsmpl
summ cnae_tarfoutp cnae_tarfintm firm_indexp if year==1994 & indsmpl
summ cnae_tarfoutp cnae_tarfintm firm_indexp if year==1997 & indsmpl
summ cnae_tarfoutp cnae_tarfintm firm_indexp if year==1998 & indsmpl

summ2tex * if indsmpl, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl10pct) name(summ_hire_aerrr_allsec) replace detail
summ2tex * if indsmpl & balarank==1, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl10pct) name(summ_hire_aerrr_balrnk1) replace detail
summ2tex * if indsmpl & balarank==3, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl10pct) name(summ_hire_aerrr_balrnk3) replace detail
summ2tex * if indsmpl & balarank==5, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl10pct) name(summ_hire_aerrr_balrnk5) replace detail
summ2tex * if indsmpl & firm_indexp, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl10pct) name(summ_hire_aerrr_indexp) replace detail

preserve
mat summ_hire_aerrr_timevar_tbl = J(8,4,.)
mat rownames summ_hire_aerrr_timevar_tbl = plant_lnempl:1990 plant_lnempl:1992 plant_lnempl:1994 plant_lnempl:1998 firm_lnlp:1990 firm_lnlp:1992 firm_lnlp:1994 firm_lnlp:1998
mat colnames summ_hire_aerrr_timevar_tbl = mean:allsec sd:allsec mean:balarank5 mean:firm_indexp
foreach var in plant_lnempl firm_lnlp {
  foreach yr in 90 92 94 98 {
    qui summ `var' if year==19`yr'
    mat summ_hire_aerrr_timevar_tbl[rownumb(summ_hire_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_hire_aerrr_timevar_tbl,"mean:allsec")] = `r(mean)'
    mat summ_hire_aerrr_timevar_tbl[rownumb(summ_hire_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_hire_aerrr_timevar_tbl,"sd:allsec")] = `r(sd)'
    qui summ `var' if year==19`yr' & balarank==5, meanonly
    mat summ_hire_aerrr_timevar_tbl[rownumb(summ_hire_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_hire_aerrr_timevar_tbl,"mean:balarank5")] = `r(mean)'
    qui summ `var' if year==19`yr' & firm_indexp, meanonly
    mat summ_hire_aerrr_timevar_tbl[rownumb(summ_hire_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_hire_aerrr_timevar_tbl,"mean:firm_indexp")] = `r(mean)'
    }
  }
est2tex summ_hire_aerrr_timevar, ready dropall path(brazrloc/estmat/v4/reg/natl10pct) replace
restore


log close
