version 8.2
clear
set logtype text
set more off
set matsize 200

capture log close
log using "brazrloc/logs/usedmachinery-natl-pianiv50.log", replace

// PIA 3-FIRM DATA 1990, 1992-1998

tempfile piadat
use cellid currno year lnoutput lnapk1 lnapq1 lnlabfbl lnlabfwh lnintmed kappa1 mu labfbl labfwh apimmo1x apmaus1x frms_obs using "brazaux/pia/random-3firm-rndmnr", clear
foreach var in lnoutput lnapk1 lnapq1 lnlabfbl lnlabfwh lnintmed labfbl labfwh apimmo1x apmaus1x {
  replace `var' = `var' / frms_obs
  label var `var' "(mean) `var'"
  }
merge cellid currno using "brazaux/pia/random-3firm-firmlist-rndmnr"
tab _m  // _m==2: cells with less than three firms excluded from 3firm-firmlist
drop if _m==2
drop cellid currno indsp contyrs _m
order firm year
sort firm year
merge firm year using "brazrloc/data/pia-data", nokeep
tab _m
drop _m
sort firm year
save `piadat'

// AUXILIARY ANNUAL DATA

tempfile auxdat
insheet using "brazrloc/auxil/origs/pib.csv", clear
keep ano populacao pib_corrente_usd
rename ano year
label var year "Calendar Year"
rename populacao population
label var population "Population [mio]"
rename pib_corrente_usd gdp_usd
replace gdp_usd = gdp_usd/1000000
label var gdp_usd "GDP [current USD bio]"
keep if year>=1986 & year<=1998
sort year
merge year using "brazrloc/auxil/globfin-annual", nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m
keep year __brl_d population _ibx50d
sort year
save `auxdat'

// NIVEL50 SECTOR DATA

tempfile niv50dat
use "brazaux/auxil/seclvl.dta", clear
foreach var in tarfoutp tarfintm reffpen secrealx fdiflw herfsale ppieu ppinam {
  rename `var' niv_`var'
  }
keep niv50 year niv_*
replace year = year+1900
sort niv50 year
save `niv50dat'

// NIVEL50 FIRM LIST
tempfile niv50lst
use firm year niv50 using "brazaux/Xpia/firms-86-98.dta", clear
bysort firm year niv50: keep if _n==1
rename firm cnpj_radic
replace year = year+1900
sort cnpj_radic year
save `niv50lst'
* check match
sort niv50 year
merge niv50 year using `niv50dat', nokeep
tab _m
count if _m~=3
if `r(N)'>0  STOP  // incomplete sector information

// NIVEL50 REGRESSIONS

local basendog "niv_tarfoutp niv_tarfintm firm_indexp"  // cut: niv_reffpen
local secexog  "subs_balcadv"
local secexo90 "subs_balcadv_90"
local secalt90 "subs_volrcadv_90"
local exoglst  "niv_secrealx niv_fdiflw niv_herfsale"
local cntrlfrm "plant_lnempl plant_indhigh plant_indcoll plant_indwhittot"
local ivlst    "niv_ppieu niv_ppinam imp_APD imp_CEE imp_NAM imp_ODV imp_OIN imp_WEU"
local intract1 "niv_tarfoutp_indexp niv_tarfintm_indexp"
local intract2 "niv_tarfoutp_balcadv niv_tarfintm_balcadv"
local intract2_90  "niv_tarfoutp_balcadv_90 niv_tarfintm_balcadv_90"
local intract3 "niv_tarfoutp_indexp_balcadv niv_tarfintm_indexp_balcadv"
local intract3_90  "niv_tarfoutp_indexp_balcadv_90 niv_tarfintm_indexp_balcadv_90"
local intract4 "niv_tarfoutp_notindprim niv_tarfintm_notindprim"  // if ~indprim
local intract5 "niv_tarfoutp_indyoung niv_tarfintm_indyoung"  // if potexper < 10
local intract6 "niv_tarfoutp_indwhite niv_tarfintm_indwhite"  // if indprof | indtech | indwhit
local intract7 "niv_tarfoutp_indfemal niv_tarfintm_indfemal"  // if indfemal
local intract8 "niv_tarfoutp_notindprim niv_tarfintm_notindprim firm_indexp_notindprim niv_balcadv_notindprim"
local intract9 "niv_tarfoutp_indexp_notindprim niv_tarfoutp_balcadv_notindprim niv_tarfintm_indexp_notindprim niv_tarfintm_balcadv_notindprim"
local addlreg  "subs_indprown_pis occ_indoutsrc"
local auxyr    "__brl_d population _ibx50d"

* accessions natl

local cntrlwrk "potexper indprof indtech indwhit indsklb"

/* XXX */ use if ~indexcl using "brazrloc/data/accessions-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf
STOP
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

* update sector information with Nivel50 when possible
sort cnpj_radic year
merge cnpj_radic year using `niv50lst', nokeep
drop _m
sort niv50 year
merge niv50 year using `niv50dat', nokeep
drop _m
foreach var in fdiflw reffpen tarfoutp tarfintm herfsale indprown_pis dollar ppieu ppinam secrealx {
  drop subs_`var'
  }

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain alternative revealed comparative-advantage measure
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge
rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* auxiliary annual data
sort year
merge year using `auxdat', nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv subs_volrcadv {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"

* interactions
gen niv_tarfoutp_indexp = niv_tarfoutp * firm_indexp
label var niv_tarfoutp_indexp "tarfoutp * indexp"
gen niv_tarfintm_indexp = niv_tarfintm * firm_indexp
label var niv_tarfintm_indexp "tarfintm * indexp"
gen niv_tarfoutp_balcadv = niv_tarfoutp * subs_balcadv
label var niv_tarfoutp_balcadv "tarfoutp * balcadv"
gen niv_tarfintm_balcadv = niv_tarfintm * subs_balcadv
label var niv_tarfintm_balcadv "tarfintm * balcadv"
gen niv_tarfoutp_indexp_balcadv = niv_tarfoutp * firm_indexp * subs_balcadv
label var niv_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen niv_tarfintm_indexp_balcadv = niv_tarfintm * firm_indexp * subs_balcadv
label var niv_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen niv_tarfoutp_notindprim = niv_tarfoutp * (~indprim) // if ~indprim
label var niv_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen niv_tarfintm_notindprim = niv_tarfintm * (~indprim) // if ~indprim
label var niv_tarfintm_notindprim "tarfintm * (~indprim)"
gen niv_tarfoutp_indyoung = niv_tarfoutp * (potexper<10) // if potexper < 10
label var niv_tarfoutp_indyoung "niv_tarfoutp * (potexper<10)"
gen niv_tarfintm_indyoung = niv_tarfintm * (potexper<10) // if potexper < 10
label var niv_tarfintm_indyoung "niv_tarfintm * (potexper<10)"
gen niv_tarfoutp_indwhite = niv_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var niv_tarfoutp_indwhite "niv_tarfoutp * (indwhit+)"
gen niv_tarfintm_indwhite = niv_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var niv_tarfintm_indwhite "niv_tarfintm * (indwhit+)"
gen niv_tarfoutp_indfemal = niv_tarfoutp * (indfemal) // if indfemal
label var niv_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen niv_tarfintm_indfemal = niv_tarfintm * (indfemal) // if indfemal
label var niv_tarfintm_indfemal "tarfintm * (indfemal)"
gen niv_tarfoutp_balcadv_90 = niv_tarfoutp * subs_balcadv_90
label var niv_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen niv_tarfintm_balcadv_90 = niv_tarfintm * subs_balcadv_90
label var niv_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen niv_tarfoutp_indexp_balcadv_90 = niv_tarfoutp * firm_indexp * subs_balcadv_90
label var niv_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen niv_tarfintm_indexp_balcadv_90 = niv_tarfintm * firm_indexp * subs_balcadv_90
label var niv_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"
gen niv_tarfoutp_volrcadv_90 = niv_tarfoutp * subs_volrcadv_90
label var niv_tarfoutp_volrcadv_90 "tarfoutp * volrcadv_90"
gen niv_tarfintm_volrcadv_90 = niv_tarfintm * subs_volrcadv_90
label var niv_tarfintm_volrcadv_90 "tarfintm * volrcadv_90"
gen niv_tarfoutp_indexp_volrcadv_90 = niv_tarfoutp * firm_indexp * subs_volrcadv_90
label var niv_tarfoutp_indexp_volrcadv_90 "tarfoutp * indexp * volrcadv_90"
gen niv_tarfintm_indexp_volrcadv_90 = niv_tarfintm * firm_indexp * subs_volrcadv_90
label var niv_tarfintm_indexp_volrcadv_90 "tarfintm * indexp * volrcadv_90"
gen subs_balcadv_up = subs_balcadv * (subs_balcadv >= subs_balcadv_90)
label var subs_balcadv_up "subs_balcadv if >= subs_balcadv_90"
gen subs_balcadv_dn = subs_balcadv * (subs_balcadv < subs_balcadv_90)
label var subs_balcadv_dn "subs_balcadv if < subs_balcadv_90"

* cluster variable
gen clusterid = niv50  // alt: gen clusterid = int(real(string(subs_ibge)+string(year))); gen clusterid = subs_ibge
label var clusterid "Nivel 50 sector cluster"
drop subs_ibge

* regressions


STOP

log close
