version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/graphs/v4/natl-maleprime"

capture log close
log using "brazrloc/logs/laborstat-graphs.log", replace


// SEPARATIONS

* national sample, all sectors
use wid year inddspl indlayoff indquit using "brazrloc/data/separations-natl-maleprime-subsibge.dta", clear
collapse (mean) inddspl indlayoff indquit, by(year)
rename year _rowname
save "brazrloc/tex/v4/labor/labstat_dspl_tbl.dta", replace
matload labstat_dspl_tbl, dropall p(brazrloc/tex/v4/labor) over
mat rename labstat_dspl_tbl labstat_dspl_natl_allsec
mat coleq labstat_dspl_natl_allsec = natl_allsec

* national sample, manufacturing only
use wid year inddspl indlayoff indquit indsubs* using "brazrloc/data/separations-natl-maleprime-subsibge.dta", clear
forvalues sec=14/26 {
  qui drop if indsubs_`sec'
  }
qui drop indsubs_1
drop indsubs*
collapse (mean) inddspl indlayoff indquit, by(year)
rename year _rowname
save "brazrloc/tex/v4/labor/labstat_dspl_tbl.dta", replace
matload labstat_dspl_tbl, dropall p(brazrloc/tex/v4/labor) over
mat rename labstat_dspl_tbl labstat_dspl_natl_manuf
mat coleq labstat_dspl_natl_manuf = natl_manuf

* metropolitan sample, all sectors
use wid year inddspl indlayoff indquit using "brazrloc/data/separations-metromale-prime-subsibge.dta", clear
collapse (mean) inddspl indlayoff indquit, by(year)
rename year _rowname
save "brazrloc/tex/v4/labor/labstat_dspl_tbl.dta", replace
matload labstat_dspl_tbl, dropall p(brazrloc/tex/v4/labor) over
mat rename labstat_dspl_tbl labstat_dspl_metro_allsec
mat coleq labstat_dspl_metro_allsec = metro_allsec

* metropolitan sample, manufacturing only
use wid year inddspl indlayoff indquit indsubs* using "brazrloc/data/separations-metromale-prime-subsibge.dta", clear
forvalues sec=14/26 {
  qui drop if indsubs_`sec'
  }
qui drop indsubs_1
drop indsubs*
collapse (mean) inddspl indlayoff indquit, by(year)
rename year _rowname
save "brazrloc/tex/v4/labor/labstat_dspl_tbl.dta", replace
matload labstat_dspl_tbl, dropall p(brazrloc/tex/v4/labor) over
mat rename labstat_dspl_tbl labstat_dspl_metro_manuf
mat coleq labstat_dspl_metro_manuf = metro_manuf

mat labstat_dspl_tbl = labstat_dspl_natl_allsec , labstat_dspl_natl_manuf , labstat_dspl_metro_allsec , labstat_dspl_metro_manuf
mat drop labstat_dspl_natl_allsec labstat_dspl_natl_manuf labstat_dspl_metro_allsec labstat_dspl_metro_manuf
est2tex labstat_dspl, replace dropall ready p(brazrloc/tex/v4/labor) fancy digits(3)

// ACCESSIONS

* national sample, all sectors
use wid year indhire using "brazrloc/data/accessions-natl-maleprime-subsibge.dta", clear
collapse (mean) indhire, by(year)
rename year _rowname
save "brazrloc/tex/v4/labor/labstat_hire_tbl.dta", replace
matload labstat_hire_tbl, dropall p(brazrloc/tex/v4/labor) over
mat rename labstat_hire_tbl labstat_hire_natl_allsec
mat coleq labstat_hire_natl_allsec = natl_allsec

* national sample, manufacturing only
use wid year indhire indsubs* using "brazrloc/data/accessions-natl-maleprime-subsibge.dta", clear
forvalues sec=14/26 {
  qui drop if indsubs_`sec'
  }
qui drop indsubs_1
drop indsubs*
collapse (mean) indhire, by(year)
rename year _rowname
save "brazrloc/tex/v4/labor/labstat_hire_tbl.dta", replace
matload labstat_hire_tbl, dropall p(brazrloc/tex/v4/labor) over
mat rename labstat_hire_tbl labstat_hire_natl_manuf
mat coleq labstat_hire_natl_manuf = natl_manuf

* metropolitan sample, all sectors
use wid year indhire using "brazrloc/data/accessions-metromale-prime-subsibge.dta", clear
collapse (mean) indhire, by(year)
rename year _rowname
save "brazrloc/tex/v4/labor/labstat_hire_tbl.dta", replace
matload labstat_hire_tbl, dropall p(brazrloc/tex/v4/labor) over
mat rename labstat_hire_tbl labstat_hire_metro_allsec
mat coleq labstat_hire_metro_allsec = metro_allsec

* metropolitan sample, manufacturing only
use wid year indhire indsubs* using "brazrloc/data/accessions-metromale-prime-subsibge.dta", clear
forvalues sec=14/26 {
  qui drop if indsubs_`sec'
  }
qui drop indsubs_1
drop indsubs*
collapse (mean) indhire, by(year)
rename year _rowname
save "brazrloc/tex/v4/labor/labstat_hire_tbl.dta", replace
matload labstat_hire_tbl, dropall p(brazrloc/tex/v4/labor) over
mat rename labstat_hire_tbl labstat_hire_metro_manuf
mat coleq labstat_hire_metro_manuf = metro_manuf

mat labstat_hire_tbl = labstat_hire_natl_allsec , labstat_hire_natl_manuf , labstat_hire_metro_allsec , labstat_hire_metro_manuf
mat drop labstat_hire_natl_allsec labstat_hire_natl_manuf labstat_hire_metro_allsec labstat_hire_metro_manuf
est2tex labstat_hire, replace dropall ready p(brazrloc/tex/v4/labor) fancy digits(3)

// SINGLE TABLE

drop _all
mat labstat_tbl = labstat_dspl_tbl , labstat_hire_tbl
mat drop labstat_dspl_tbl labstat_hire_tbl
est2tex labstat, replace dropall ready p(brazrloc/tex/v4/labor) fancy digits(3)

matorder labstat_tbl, m(labstat_dsplhire_tbl) ifc(natl_allsec_inddspl natl_manuf_inddspl metro_allsec_inddspl metro_manuf_inddspl natl_allsec_indhire natl_manuf_indhire metro_allsec_indhire metro_manuf_indhire)
est2tex labstat_dsplhire, replace dropall ready p(brazrloc/tex/v4/labor) fancy digits(3) extracols(4)
drop _all


// TABULATE ORDERED DURATIONS

* variable names for est2tex
est2extlbl, addto(rehircat_natl_subs) intex($root/brazrloc/%stata/rowlbl-brazrloc) path(brazrloc/tex/v4/natl-maleprime/laborstats) replace
est2extlbl, addto(rehircat_metro_subs) retain path(brazrloc/tex/v4/metromale-prime/laborstats) replace
est2extlbl, addto(rehircat_natl_cnae) retain path(brazrloc/tex/v4/natl-maleprime/laborstats) replace
est2extlbl, addto(rehircat_metro_cnae) retain path(brazrloc/tex/v4/metromale-prime/laborstats) replace
est2extlbl, addto(rehircat) retain path(brazrloc/tex/v4/labor) replace

* national sample, subsector IBGE
use wid year rehircat using "brazrloc/data/ordered-durations-natl-maleprime-subsibge.dta", clear
gen byte _dummy = 1
tabl2tex _dummy if year>=1990 & year<=1997, type(sum) r(rehircat) c(year) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(rehircat_natl_subs) fancy replace over nolog
local totcol = colsof(rehircat_natl_subs_tbl)
local totrow = rowsof(rehircat_natl_subs_tbl)
local totrow1 = `totrow'-1
local colnames : colfullnames rehircat_natl_subs_tbl
tokenize `colnames'
forvalues col = 1/`totcol' {
  local newname = subinstr(subinstr("``col''","_dummy_","yr",.),"_","",.)
  matname rehircat_natl_subs_tbl `newname', columns(`col') explicit
  forvalues row = 1/`totrow1' {
    mat rehircat_natl_subs_tbl[`row',`col'] = rehircat_natl_subs_tbl[`row',`col']/rehircat_natl_subs_tbl[`totrow',`col']
    }
  mat rehircat_natl_subs_tbl[`totrow',`col'] = rehircat_natl_subs_tbl[`totrow',`col'] * 100 / 1000 // national 1-percent sample
  }
matname rehircat_natl_subs_tbl count_pop, rows(`totrow') explicit
est2tex rehircat_natl_subs, ready replace path(brazrloc/tex/v4/natl-maleprime/laborstats) fancy digits(3)

* metropolitan sample, subsector IBGE
use wid year rehircat using "brazrloc/data/ordered-durations-metromale-prime-subsibge.dta", clear
gen byte _dummy = 1
tabl2tex _dummy if year>=1990 & year<=1997, type(sum) r(rehircat) c(year) p(brazrloc/tex/v4/metromale-prime/laborstats) name(rehircat_metro_subs) fancy replace over nolog
local totcol = colsof(rehircat_metro_subs_tbl)
local totrow = rowsof(rehircat_metro_subs_tbl)
local totrow1 = `totrow'-1
local colnames : colfullnames rehircat_metro_subs_tbl
tokenize `colnames'
forvalues col = 1/`totcol' {
  local newname = subinstr(subinstr("``col''","_dummy_","yr",.),"_","",.)
  matname rehircat_metro_subs_tbl `newname', columns(`col') explicit
  forvalues row = 1/`totrow1' {
    mat rehircat_metro_subs_tbl[`row',`col'] = rehircat_metro_subs_tbl[`row',`col']/rehircat_metro_subs_tbl[`totrow',`col']
    }
  mat rehircat_metro_subs_tbl[`totrow',`col'] = rehircat_metro_subs_tbl[`totrow',`col'] * 20 / 1000  // metropolitan 5-percent sample
  }
matname rehircat_metro_subs_tbl count_pop, rows(`totrow') explicit
est2tex rehircat_metro_subs, ready replace path(brazrloc/tex/v4/metromale-prime/laborstats) fancy digits(3)

* national sample, CNAE
use wid year rehircat using "brazrloc/data/ordered-durations-natl-maleprime-cnae.dta", clear
gen byte _dummy = 1
tabl2tex _dummy if year>=1990 & year<=1997, type(sum) r(rehircat) c(year) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(rehircat_natl_cnae) fancy replace over nolog
local totcol = colsof(rehircat_natl_cnae_tbl)
local totrow = rowsof(rehircat_natl_cnae_tbl)
local totrow1 = `totrow'-1
local colnames : colfullnames rehircat_natl_cnae_tbl
tokenize `colnames'
forvalues col = 1/`totcol' {
  local newname = subinstr(subinstr("``col''","_dummy_","yr",.),"_","",.)
  matname rehircat_natl_cnae_tbl `newname', columns(`col') explicit
  forvalues row = 1/`totrow1' {
    mat rehircat_natl_cnae_tbl[`row',`col'] = rehircat_natl_cnae_tbl[`row',`col']/rehircat_natl_cnae_tbl[`totrow',`col']
    }
  mat rehircat_natl_cnae_tbl[`totrow',`col'] = rehircat_natl_cnae_tbl[`totrow',`col'] * 100 / 1000  // national 1-percent sample
  }
matname rehircat_natl_cnae_tbl count_pop, rows(`totrow') explicit
est2tex rehircat_natl_cnae, ready replace path(brazrloc/tex/v4/natl-maleprime/laborstats) fancy digits(3)

* metropolitan sample, CNAE
use wid year rehircat using "brazrloc/data/ordered-durations-metromale-prime-cnae.dta", clear
gen byte _dummy = 1
tabl2tex _dummy if year>=1990 & year<=1997, type(sum) r(rehircat) c(year) p(brazrloc/tex/v4/metromale-prime/laborstats) name(rehircat_metro_cnae) fancy replace over nolog
local totcol = colsof(rehircat_metro_cnae_tbl)
local totrow = rowsof(rehircat_metro_cnae_tbl)
local totrow1 = `totrow'-1
local colnames : colfullnames rehircat_metro_cnae_tbl
tokenize `colnames'
forvalues col = 1/`totcol' {
  local newname = subinstr(subinstr("``col''","_dummy_","yr",.),"_","",.)
  matname rehircat_metro_cnae_tbl `newname', columns(`col') explicit
  forvalues row = 1/`totrow1' {
    mat rehircat_metro_cnae_tbl[`row',`col'] = rehircat_metro_cnae_tbl[`row',`col']/rehircat_metro_cnae_tbl[`totrow',`col']
    }
  mat rehircat_metro_cnae_tbl[`totrow',`col'] = rehircat_metro_cnae_tbl[`totrow',`col'] * 20 / 1000  // metropolitan 5-percent sample
  }
matname rehircat_metro_cnae_tbl count_pop, rows(`totrow') explicit
est2tex rehircat_metro_cnae, ready replace path(brazrloc/tex/v4/metromale-prime/laborstats) fancy digits(3)

* joint table of totals
drop _all
foreach mat in natl_subs metro_subs natl_cnae metro_cnae {
  matorder rehircat_`mat'_tbl, m(rehircat_`mat'_tbl) ifc(total) over
  matname rehircat_`mat'_tbl `mat'_90_97, columns(1) explicit
  }
mat rehircat_tbl = rehircat_natl_subs_tbl , rehircat_metro_subs_tbl , rehircat_natl_cnae_tbl , rehircat_metro_cnae_tbl
mat drop rehircat_natl_subs_tbl rehircat_metro_subs_tbl rehircat_natl_cnae_tbl rehircat_metro_cnae_tbl
est2tex rehircat, ready replace path(brazrloc/tex/v4/labor) fancy digits(3) extracols(2)


// GRAPHS

use "brazrloc/tex/v4/labor/labstat_tbl.dta", clear
gen int year = int(real(_rowname))
label var year "Calendar year"

* separation and accession graphs

graph bar natl_allsec_inddspl natl_allsec_indhire, over(year) legend( label(1 "Separations") label(2 "Accessions") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl-maleprime/allsec-dsplhire.eps", replace

graph bar natl_manuf_inddspl natl_manuf_indhire, over(year) legend( label(1 "Separations") label(2 "Accessions") ) graphregion(color(white)) scheme(sj) 
graph export "brazrloc/graphs/v4/natl-maleprime/manuf-dsplhire.eps", replace

graph bar metro_allsec_inddspl metro_allsec_indhire, over(year) legend( label(1 "Separations") label(2 "Accessions") ) graphregion(color(white)) scheme(sj) 
graph export "brazrloc/graphs/v4/metromale-prime/allsec-dsplhire.eps", replace

graph bar metro_manuf_inddspl metro_manuf_indhire, over(year) legend( label(1 "Separations") label(2 "Accessions") ) graphregion(color(white)) scheme(sj) 
graph export "brazrloc/graphs/v4/metromale-prime/manuf-dsplhire.eps", replace

* layoff, quit and accession graphs

keep year *_indlayoff *_indquit
gen str10 category = "Separation"
append using "brazrloc/tex/v4/labor/labstat_tbl.dta"
replace year = int(real(_rowname)) if year==.
keep year category *_indlayoff *_indquit *_indhire
replace category="Accession" if category==""
foreach grp in natl_allsec natl_manuf metro_allsec metro_manuf {
  replace `grp'_indhire = . if category=="Separation"
  replace `grp'_indlayoff = . if category=="Accession"
  replace `grp'_indquit = . if category=="Accession"
  }
order year category
sort year category
* replace category = substr(category,1,3) + "."

graph bar natl_manuf_indlayoff natl_manuf_indquit natl_manuf_indhire if year>=1986 & year<=1998, over(category, descending label(nolabels)) over(year) stack blabel(bar, position(inside) format(%9.2f)) bar(1, blwidth(thick) bcolor(gs6) ) bar(2, blwidth(thick) bcolor(gs8) ) bar(3, blwidth(thick) bcolor(gs10) ) graphregion(color(white)) scheme(sj) legend( label(1 "Layoffs") label(2 "Quits") label(3 "Accessions") )
graph export "brazrloc/graphs/v4/natl-maleprime/manuf-layoffquithire-98.eps", replace

graph bar natl_allsec_indlayoff natl_allsec_indquit natl_allsec_indhire if year>=1986 & year<=1997, over(category, descending label(nolabels)) over(year) stack blabel(bar, position(inside) format(%9.2f)) bar(1, blwidth(thick) bcolor(gs6) ) bar(2, blwidth(thick) bcolor(gs8) ) bar(3, blwidth(thick) bcolor(gs10) ) graphregion(color(white)) scheme(sj) legend( label(1 "Layoffs") label(2 "Quits") label(3 "Accessions") )
graph export "brazrloc/graphs/v4/natl-maleprime/allsec-layoffquithire.eps", replace

graph bar natl_manuf_indlayoff natl_manuf_indquit natl_manuf_indhire if year>=1986 & year<=1997, over(category, descending label(nolabels)) over(year) stack blabel(bar, position(inside) format(%9.2f)) bar(1, blwidth(thick) bcolor(gs6) ) bar(2, blwidth(thick) bcolor(gs8) ) bar(3, blwidth(thick) bcolor(gs10) ) graphregion(color(white)) scheme(sj) legend( label(1 "Layoffs") label(2 "Quits") label(3 "Accessions") )
graph export "brazrloc/graphs/v4/natl-maleprime/manuf-layoffquithire.eps", replace

graph bar metro_allsec_indlayoff metro_allsec_indquit metro_allsec_indhire if year>=1986 & year<=1997, over(category, descending label(nolabels)) over(year) stack blabel(bar, position(inside) format(%9.2f)) bar(1, blwidth(thick) bcolor(gs6) ) bar(2, blwidth(thick) bcolor(gs8) ) bar(3, blwidth(thick) bcolor(gs10) ) graphregion(color(white)) scheme(sj) legend( label(1 "Layoffs") label(2 "Quits") label(3 "Accessions") )
graph export "brazrloc/graphs/v4/metromale-prime/allsec-layoffquithire.eps", replace

graph bar metro_manuf_indlayoff metro_manuf_indquit metro_manuf_indhire if year>=1986 & year<=1997, over(category, descending label(nolabels)) over(year) stack blabel(bar, position(inside) format(%9.2f)) bar(1, blwidth(thick) bcolor(gs6) ) bar(2, blwidth(thick) bcolor(gs8) ) bar(3, blwidth(thick) bcolor(gs10) ) graphregion(color(white)) scheme(sj) legend( label(1 "Layoffs") label(2 "Quits") label(3 "Accessions") )
graph export "brazrloc/graphs/v4/metromale-prime/manuf-layoffquithire.eps", replace


log close
